==> libstpk-0.9.9.1.tar.gz: libstpk-0.9.9.1/src/cloud_const.f90 <==
!-----------------------------------------------------------------------
!     Copyright (C) 2000-2013 GFD Dennou Club. All rights reserved.
!-----------------------------------------------------------------------

module Cloud_Const  ! ʪ
  ! ñ̤Ϥ٤ MKS ñ̷
  ! ͤ
  ! * Tsuboki and Sakakibara, 2007
  ! * Murakami, 1990
  ! .
  ! ƥ, ®٤ηѥ᡼, ̩, ǻ٤Ǥ.
  implicit none
  real, parameter :: auc=2.98e7
  real, parameter :: buc=2.0
  real, parameter :: cuc=1.0
  real, parameter :: aur=842.0
  real, parameter :: bur=0.8
  real, parameter :: cur=0.5
  real, parameter :: aui=700.0
  real, parameter :: bui=1.0
  real, parameter :: cui=0.33
  real, parameter :: aus=17.0
  real, parameter :: bus=0.5
  real, parameter :: cus=0.5
  real, parameter :: aug=124.0
  real, parameter :: bug=0.64
  real, parameter :: cug=0.5

  real, parameter :: rhoi=5.0e2  ! ɹ̩ [kg/m^3]
  real, parameter :: rhos=84.0   ! ̩ [kg/m^3]
  real, parameter :: rhog=3.0e2  ! Ǥ̩ [kg/m^3]

  real, parameter :: nr0=8.0e6   !  y ǻ [1/m^4]
  real, parameter :: ns0=1.8e6   !  y ǻ [1/m^4]
  real, parameter :: ng0=1.1e6   ! Ǥ y ǻ [1/m^4]

  real, parameter :: mi0=1.0e-12    ! ɹκǾ [kg]
  real, parameter :: ms0=1.76e-10   ! κǾ [kg]
  real, parameter :: mg0=7.0e-10    ! ǤκǾ [kg]
  real, parameter :: mi0max=1.4e-10    ! ǤκǾ [kg]

  real, parameter :: epi=4.2     ! ɹͶΨ
  real, parameter :: epw=80.0    ! ͶΨ

  real, parameter :: Ci=2.0e3    ! ɹ갵Ǯ [J/K kg]
  real, parameter :: Cw=4.17e3    ! 갵Ǯ [J/K kg]

  real, parameter :: Ecc=0.55       ! ƱΤªΨ
  real, parameter :: Ess=0.1        ! ƱΤ­Ψ
  real, parameter :: Eii=0.1        ! ɹƱΤ­Ψ

  real, parameter :: Nc=1.0e8       ! γοǻ [1/m^3]
  real, parameter :: Dcm=20.0e-6    ! γ׳ʿľ [m]

  real, parameter :: Fea1=12.96     ! Ferrier η 1
  real, parameter :: Feb1=0.639     ! Ferrier η 2
  real, parameter :: HVB=4.5        ! Huffmann and Vail η
  real, parameter :: FLT1=1.0e-2    ! Fletcher η 1 [1/m^3]
  real, parameter :: FLT2=0.6       ! Fletcher η 2 [1/K]
  real, parameter :: Ni01=1.0e3     ! Ferrier γҿ 1 [1/m^3]
  real, parameter :: Ni02=50.0      ! Ferrier γҿ 2 [1/m^3]
  real, parameter :: Bigga=0.66     ! Bigg η 1 [1/K]
  real, parameter :: Biggb=100.0    ! Bigg η 2 [1/m^3s]
  real, parameter :: Na0=2.0e5      ! ܿˤοǻٷ [1/m^3]
  real, parameter :: AERO=3.0e-7    ! γҤȾ [m]
  real, parameter :: Sc=0.6         ! ߥåȿ
  real, parameter :: kappaa=2.4e-2  ! ǮƳΨ [J/m s K]
  real, parameter :: kappaaero=2.4e-1  ! ǮƳΨ [J/m s K]
  real, parameter :: spii=0.25      ! ɹ®٤Υڥȥʬ
  real, parameter :: tref=293.15    ! ಹ [K]
  real, parameter :: MFP0=6.6e-8    ! p00, tref ǤʿѼͳ [m]
  real, parameter :: Raero=3.0e-7   ! γҤȾ [m]

  real, parameter :: qthres=1.0e-12 ! ʪ׻ζŷʪ [kg/kg]
  real, parameter :: tscp=233.16    ! Ѿ֤κ㲹 [K]

end module

==> libstpk-0.9.9.2.tar.gz: libstpk-0.9.9.2/src/cloud_const.f90 <==
!-----------------------------------------------------------------------
!     Copyright (C) 2000-2013 GFD Dennou Club. All rights reserved.
!-----------------------------------------------------------------------

module Cloud_Const  ! ʪ
  ! ñ̤Ϥ٤ MKS ñ̷
  ! ͤ
  ! * Tsuboki and Sakakibara, 2007
  ! * Murakami, 1990
  ! .
  ! ƥ, ®٤ηѥ᡼, ̩, ǻ٤Ǥ.
  implicit none
  real, parameter :: auc=2.98e7
  real, parameter :: buc=2.0
  real, parameter :: cuc=1.0
  real, parameter :: aur=842.0
  real, parameter :: bur=0.8
  real, parameter :: cur=0.5
  real, parameter :: aui=770.0
!  real, parameter :: aui=700.0
  real, parameter :: bui=1.0
  real, parameter :: cui=0.33
  real, parameter :: aus=27.0
!  real, parameter :: aus=17.0
  real, parameter :: bus=0.5
  real, parameter :: cus=0.5
  real, parameter :: aug=132.0
!  real, parameter :: aug=124.0
  real, parameter :: bug=0.64
  real, parameter :: cug=0.5

  real, parameter :: rhoi=5.0e2  ! ɹ̩ [kg/m^3]
  real, parameter :: rhos=84.0   ! ̩ [kg/m^3]
  real, parameter :: rhog=3.0e2  ! Ǥ̩ [kg/m^3]

  real, parameter :: nr0=8.0e6   !  y ǻ [1/m^4]
  real, parameter :: ns0=1.8e6   !  y ǻ [1/m^4]
  real, parameter :: ng0=1.1e6   ! Ǥ y ǻ [1/m^4]

  real, parameter :: mi0=1.0e-12    ! ɹκǾ [kg]
  real, parameter :: ms0=1.76e-10   ! κǾ [kg]
  real, parameter :: mg0=7.0e-10    ! ǤκǾ [kg]
  real, parameter :: mi0max=1.4e-10    ! ǤκǾ [kg]

  real, parameter :: epi=4.2     ! ɹͶΨ
  real, parameter :: epw=80.0    ! ͶΨ

  real, parameter :: Ci=2.0e3    ! ɹ갵Ǯ [J/K kg]
  real, parameter :: Cw=4.17e3    ! 갵Ǯ [J/K kg]

  real, parameter :: Ecc=0.55       ! ƱΤªΨ
  real, parameter :: Ess=0.1        ! ƱΤ­Ψ
  real, parameter :: Eii=0.1        ! ɹƱΤ­Ψ

  real, parameter :: Nc=1.0e8       ! γοǻ [1/m^3]
  real, parameter :: Dcm=20.0e-6    ! γ׳ʿľ [m]

  real, parameter :: Fea1=12.96     ! Ferrier η 1
  real, parameter :: Feb1=0.639     ! Ferrier η 2
  real, parameter :: HVB=4.5        ! Huffmann and Vail η
  real, parameter :: FLT1=1.0e-2    ! Fletcher η 1 [1/m^3]
  real, parameter :: FLT2=0.6       ! Fletcher η 2 [1/K]
  real, parameter :: Ni01=1.0e3     ! Ferrier γҿ 1 [1/m^3]
  real, parameter :: Ni02=50.0      ! Ferrier γҿ 2 [1/m^3]
  real, parameter :: Bigga=0.66     ! Bigg η 1 [1/K]
  real, parameter :: Biggb=100.0    ! Bigg η 2 [1/m^3s]
  real, parameter :: Na0=2.0e5      ! ܿˤοǻٷ [1/m^3]
  real, parameter :: AERO=3.0e-7    ! γҤȾ [m]
  real, parameter :: Sc=0.6         ! ߥåȿ
  real, parameter :: kappaa=2.4e-2  ! ǮƳΨ [J/m s K]
  real, parameter :: kappaaero=2.4e-1  ! ǮƳΨ [J/m s K]
  real, parameter :: spii=0.25      ! ɹ®٤Υڥȥʬ
  real, parameter :: tref=293.15    ! ಹ [K]
  real, parameter :: MFP0=6.6e-8    ! p00, tref ǤʿѼͳ [m]
  real, parameter :: Raero=3.0e-7   ! γҤȾ [m]

  real, parameter :: qthres=1.0e-12 ! ʪ׻ζŷʪ [kg/kg]
  real, parameter :: tscp=233.16    ! Ѿ֤κ㲹 [K]

end module
